package com.ruoyi.system.service;

import com.ruoyi.system.domain.notice.ZxNotice;

import java.util.List;

/**
 * 政协通知公告Service接口
 * 
 * @author boman
 * @date 2024-03-05
 */
public interface IZxNoticeService 
{
    /**
     * 查询政协通知公告
     * 
     * @param zxNoticeId 政协通知公告主键
     * @return 政协通知公告
     */
    public ZxNotice selectZxNoticeByZxNoticeId(Long zxNoticeId);

    /**
     * 查询政协通知公告列表
     * 
     * @param zxNotice 政协通知公告
     * @return 政协通知公告集合
     */
    public List<ZxNotice> selectZxNoticeList(ZxNotice zxNotice);

    /**
     * 新增政协通知公告
     * 
     * @param zxNotice 政协通知公告
     * @return 结果
     */
    public int insertZxNotice(ZxNotice zxNotice);

    /**
     * 修改政协通知公告
     * 
     * @param zxNotice 政协通知公告
     * @return 结果
     */
    public int updateZxNotice(ZxNotice zxNotice);

    /**
     * 批量删除政协通知公告
     * 
     * @param zxNoticeIds 需要删除的政协通知公告主键集合
     * @return 结果
     */
    public int deleteZxNoticeByZxNoticeIds(Long[] zxNoticeIds);

    /**
     * 删除政协通知公告信息
     * 
     * @param zxNoticeId 政协通知公告主键
     * @return 结果
     */
    public int deleteZxNoticeByZxNoticeId(Long zxNoticeId);
}
